(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)
(* $Id: RonInit.nb,v 1.4 2012/02/21 14:45:52 rholzloe Exp $ *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       220,          8]
NotebookDataLength[     77414,       2244]
NotebookOptionsPosition[     73188,       2123]
NotebookOutlinePosition[     73594,       2140]
CellTagsIndexPosition[     73551,       2137]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"RonInitwasLoaded", "=", 
   RowBox[{"AbsoluteTime", "[", "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["RonInit", "Title",
 InitializationGroup->True],

Cell[TextData[StyleBox["Basic routines and definitions\nRon Holzloehner",
 FontFamily->"Verdana"]], "Text",
 InitializationGroup->True],

Cell["\<\
Physical constants
\tkB: Boltzmann's k
\th: Planck's constant [Js]
\tc0: vaccum speed of light [m/s]\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"constPhys", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"kB", "\[Rule]", "1.380650424*^-23"}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"Boltzmann", "'"}], "s", " ", 
       RowBox[{"constant", " ", "[", "J", "]"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"h", "\[Rule]", "6.626176*^-34"}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"Planck", "'"}], "s", " ", 
       RowBox[{"constant", " ", "[", "Js", "]"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"hbar", "\[Rule]", 
      RowBox[{"6.626176*^-34", "/", 
       RowBox[{"(", 
        RowBox[{"2", "\[Pi]"}], ")"}]}]}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{"h", " ", 
       RowBox[{"bar", " ", "[", "Js", "]"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"c0", "\[Rule]", "2.99792458*^8"}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{"vacuum", " ", "speed", " ", "of", " ", 
       RowBox[{"light", " ", "[", 
        RowBox[{"m", "/", "s"}], "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"\[Epsilon]0", "\[Rule]", "8.854187817620*^-12"}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{"vaccum", " ", 
       RowBox[{"permittivity", " ", "[", 
        RowBox[{"As", "/", 
         RowBox[{"(", "Vm", ")"}]}], "]"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"Z0", "\[Rule]", "376.72979512339"}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{"vacuum", " ", 
       RowBox[{"impedance", " ", "[", "Ohm", "]"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"gEarth", "\[Rule]", "9.80665"}], ",", "   ", 
     RowBox[{"(*", " ", 
      RowBox[{
      "conventional", " ", "standard", " ", "value", " ", "of", " ", "g", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"gravity", " ", "acceleration", " ", "on", " ", "Earth"}], 
         ")"}], " ", "[", 
        RowBox[{"m", "/", 
         RowBox[{"s", "^", "2"}]}], "]"}]}], "  ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"nAir", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"1.0", "+", "27235.9*^-8"}], ")"}]}]}], "   ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{
      "refractive", " ", "index", " ", "of", " ", "air", " ", "from", " ", 
       "Edlen", " ", "formula", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"589", "nm"}], ",", " ", 
          RowBox[{"1013", "hPa"}], ",", " ", 
          RowBox[{"20", "C"}]}], ")"}], ".", " ", "At"}], " ", "1178", "nm"}],
       ",", " ", 
      RowBox[{"it", " ", "would", " ", "be", " ", 
       RowBox[{"(", 
        RowBox[{"1.0", "+", "26900.1*^-8"}], ")"}]}]}], " ", "*)"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Degrees", " ", "to", " ", "radian"}], ",", " ", 
    RowBox[{"and", " ", 
     RowBox[{"back", " ", "--"}], " ", "defined", " ", "as", " ", "exact", 
     " ", "numbers"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Deg2Rad", "=", 
     RowBox[{"\[Pi]", "/", "180"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Rad2Deg", "=", 
     RowBox[{"1", "/", "Deg2Rad"}]}], ";"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Arcseconds", " ", "to", " ", "radian"}], ",", " ", 
    RowBox[{"and", " ", "back"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Rad2AS", "=", 
    RowBox[{
     RowBox[{"180", "/", "\[Pi]"}], "*", "3600"}]}], ";", " ", 
   RowBox[{"AS2Rad", "=", 
    RowBox[{"1", "/", "Rad2AS"}]}], ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Convert", " ", "Gaussian", " ", "sigma", " ", "to", " ", "FWHM"}], ",", 
    " ", 
    RowBox[{
     RowBox[{"hence", " ", "for", "  ", "f", 
      RowBox[{"(", "x", ")"}]}], "=", 
     RowBox[{"exp", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"x", "^", "2"}]}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"\[Sigma]", "^", "2"}]}], ")"}]}], ")"}]}]}]}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"\[Sigma]2FWHM", "=", 
    RowBox[{"2", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"2", 
       RowBox[{"Log", "[", "2", "]"}]}], "]"}]}]}], ";", 
   RowBox[{"FWHM2\[Sigma]", "=", 
    RowBox[{"1", "/", "\[Sigma]2FWHM"}]}], ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Product", " ", "of", " ", "FWHM", " ", "of", " ", "magnitude", " ", 
     "squared", " ", "Gaussian", " ", "in", " ", "time", " ", "domain", " ", 
     "and", " ", "its", " ", "Fourier", " ", "transform", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"equals", " ", "0.441"}], "..."}], ")"}], 
     "\[IndentingNewLine]", "We", " ", "use", " ", "the", " ", "fact", " ", 
     "that", " ", "the", " ", "Fourier", " ", "transform", " ", "of", " ", 
     "exp", 
     RowBox[{"(", 
      RowBox[{"-", 
       SuperscriptBox["at", "2"]}], ")"}], " ", "is", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Pi]", "/", "a"}], ")"}], 
      RowBox[{
       RowBox[{"-", "1"}], "/", "2"}]], "exp", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Omega]", "2"]}], "/", 
       RowBox[{"(", 
        RowBox[{"4", "a"}], ")"}]}], ")"}], " ", "and", " ", "\[Omega]"}], 
    "=", 
    RowBox[{"2", "\[Pi]f"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ClearAll", "[", 
     RowBox[{"a", ",", "\[Sigma]t", ",", "\[Sigma]t"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FWHMtFWHMfMag", "=", 
     RowBox[{
      RowBox[{"\[Sigma]p", "*", "\[Sigma]t", "*", 
       RowBox[{"\[Sigma]2FWHM", "^", "2"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", "\[Pi]"}], ")"}], "^", "2"}], "/", "4"}], "/", 
              "a"}]}], "\[Equal]", 
            RowBox[{
             RowBox[{"1", "/", 
              RowBox[{"\[Sigma]p", "^", "2"}]}], "/", "2"}]}], ",", 
           "\[Sigma]p"}], "]"}], "\[LeftDoubleBracket]", 
         RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"2", "a"}], "\[Equal]", 
            RowBox[{
             RowBox[{"1", "/", "2"}], "/", 
             RowBox[{"\[Sigma]t", "^", "2"}]}]}], ",", "\[Sigma]t"}], "]"}], 
         "\[LeftDoubleBracket]", 
         RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], "}"}]}]}], 
    ";"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell["Code", "Section",
 InitializationGroup->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<PlotLegends`\>\"", "]"}], ";"}]], "Input"],

Cell[TextData[StyleBox["Ron's line plot routine for production plots. We can \
set some variables here and still change them after the plot routines have \
been defined since Plot[] has the attributes HoldAll.",
 FontFamily->"Verdana"]], "Text",
 InitializationGroup->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"ClearAll", "[", "th125", "]"}], ";", 
  RowBox[{"ronPlotStyle", "=", 
   RowBox[{"Thickness", "[", "th125", "]"}]}], ";", 
  RowBox[{"th125", "=", "0.001"}], ";", 
  RowBox[{"ronPlotfs", "=", "12"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ronPlot", "[", "x___", "]"}], ":=", 
   RowBox[{"Plot", "[", 
    RowBox[{"x", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
        "ronPlotfs"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"6", " ", "72"}]}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Blue", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Darker", "[", "Green", "]"}], ",", "ronPlotStyle"}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Cyan", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Yellow", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Brown", ",", "ronPlotStyle"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 InitializationGroup->True],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ronLogPlot", "[", "x___", "]"}], ":=", 
   RowBox[{"LogPlot", "[", 
    RowBox[{"x", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
        "ronPlotfs"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"6", " ", "72"}]}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Blue", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Darker", "[", "Green", "]"}], ",", "ronPlotStyle"}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Cyan", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Yellow", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Brown", ",", "ronPlotStyle"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ronLogLogPlot", "[", "x___", "]"}], ":=", 
   RowBox[{"LogLogPlot", "[", 
    RowBox[{"x", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
        "ronPlotfs"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"6", " ", "72"}]}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Blue", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Darker", "[", "Green", "]"}], ",", "ronPlotStyle"}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Cyan", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Yellow", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Brown", ",", "ronPlotStyle"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ronListLinePlot", "[", "x___", "]"}], ":=", 
   RowBox[{"ListLinePlot", "[", 
    RowBox[{"x", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
        "ronPlotfs"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"6", " ", "72"}]}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Blue", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Darker", "[", "Green", "]"}], ",", "ronPlotStyle"}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Cyan", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Yellow", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Brown", ",", "ronPlotStyle"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ronListLogPlot", "[", "x___", "]"}], ":=", 
   RowBox[{"ListLogPlot", "[", 
    RowBox[{"x", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
        "ronPlotfs"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"6", " ", "72"}]}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Blue", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Darker", "[", "Green", "]"}], ",", "ronPlotStyle"}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Cyan", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Yellow", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Brown", ",", "ronPlotStyle"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ronListLogLogPlot", "[", "x___", "]"}], ":=", 
   RowBox[{"ListLogLogPlot", "[", 
    RowBox[{"x", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
        "ronPlotfs"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"6", " ", "72"}]}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Blue", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Darker", "[", "Green", "]"}], ",", "ronPlotStyle"}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Cyan", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Yellow", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Brown", ",", "ronPlotStyle"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ronListPlot", "[", "x___", "]"}], ":=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"x", ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
        "ronPlotfs"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"6", " ", "72"}]}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Blue", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Darker", "[", "Green", "]"}], ",", "ronPlotStyle"}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Cyan", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Yellow", ",", "ronPlotStyle"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Brown", ",", "ronPlotStyle"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell["Ron's contour plot routine for production plots", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ronListContourPlot", "[", "x___", "]"}], ":=", 
   RowBox[{"ListContourPlot", "[", 
    RowBox[{"x", ",", 
     RowBox[{"InterpolationOrder", "\[Rule]", "3"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"6", " ", "72"}]}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
        "ronPlotfs"}], "}"}]}], ",", 
     RowBox[{"ContourLabels", "\[Rule]", "All"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "\"\<FruitPunchColors\>\""}], ",", 
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}], ",", 
     RowBox[{"Contours", "\[Rule]", "20"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "Automatic"}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 InitializationGroup->True],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"ronPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "4"}], ")"}]}], ",", 
      RowBox[{"x", "^", 
       RowBox[{"(", 
        RowBox[{"3", "/", "4"}], ")"}]}], ",", 
      RowBox[{"x", "^", 
       RowBox[{"(", 
        RowBox[{"3", "/", "2"}], ")"}]}], ",", 
      RowBox[{"x", "^", 
       RowBox[{"(", 
        RowBox[{"5", "/", "2"}], ")"}]}], ",", 
      RowBox[{"x", "^", 
       RowBox[{"(", 
        RowBox[{"5.5", "/", "2"}], ")"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "2"}], "}"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}]}], ",", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Thickness", "[", "0.0002", "]"}], " ", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1000", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}]}]}], 
   "]"}], " ", "*)"}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[{
 "FFT and inverse FFT, same as in Matlab. Test e.g. by\nx12 = {1, 1, 2, 2, 1, \
1, 0, 0};\nChop[fft[x12]] // MatrixForm\nChop[ifft[fft[x12]] - x12] // \
MatrixForm\nand compare with Matlab\nUse ifft[] to go from time to frequency \
domain (sic!), and fft[] to go from frequency to time.\nAbs[ifft[f[t]]]^2 \
yields the power spectrum with the normalization \
Total[psd[\[Omega]]]==Mean[Abs[f[t]]^2].\n\nSpeed comparison with Matlab:\n\t\
t1=cputime(); for k=1:10000,ll1=fft(ifft(dd));end; cputime()-t1\ntakes 9.42s \
on the desktop Dell and 8.7s on soap\n\tdd = whiteNoise[1.0, 2^13];\n\t\
Timing[For[k = 1, k <= 10000, k++, ll1 = Fourier[InverseFourier[dd]];]]\n\
takes 8.86s, hence ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is even faster at length 2^13!"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"fft", "[", "x_", "]"}], ":=", 
   RowBox[{"Fourier", "[", 
    RowBox[{"x", ",", 
     RowBox[{"FourierParameters", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ifft", "[", "x_", "]"}], ":=", 
   RowBox[{"InverseFourier", "[", 
    RowBox[{"x", ",", 
     RowBox[{"FourierParameters", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}]}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"fft", "[", "x_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"y", "=", 
         RowBox[{"Norm", "[", "x", "]"}]}], ",", "f1"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"y", "\[Equal]", "0.0"}], ",", "\[IndentingNewLine]", "x", 
        ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"f1", "=", 
          RowBox[{"1000.0", "/", "y"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.0", "/", "f1"}], ")"}], "*", 
          RowBox[{"Fourier", "[", 
           RowBox[{
            RowBox[{"f1", "*", "x"}], ",", 
            RowBox[{"FourierParameters", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}], "}"}]}]}], "]"}]}]}]}], 
       "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ifft", "[", "x_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"y", "=", 
         RowBox[{"Norm", "[", "x", "]"}]}], ",", "f1"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"y", "\[Equal]", "0.0"}], ",", "\[IndentingNewLine]", "x", 
        ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"f1", "=", 
          RowBox[{"1000.0", "/", "y"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.0", "/", "f1"}], ")"}], "*", 
          RowBox[{"InverseFourier", "[", 
           RowBox[{
            RowBox[{"f1", "*", "x"}], ",", 
            RowBox[{"FourierParameters", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}], "}"}]}]}], "]"}]}]}]}], 
       "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "*)"}]], "Input"],

Cell["\<\
Makes a symmetric vector -nh,-nh+1,...,n-1-nh, where nh = Floor[n/2]. \
Examples: n=7: -3,-2,...+3, for n=8: -4,-3,...3. Such vectors are useful to \
compute the frequency offsets in the FFT (use ifftshift(symFFTVec[n]))\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"symFFTVec", "[", "n_", "]"}], ":=", 
   RowBox[{"Range", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Floor", "[", 
       RowBox[{"n", "/", "2"}], "]"}]}], ",", 
     RowBox[{"n", "-", "1", "-", 
      RowBox[{"Floor", "[", 
       RowBox[{"n", "/", "2"}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell["\<\
Same routines as in Matlab. Make sure that fftshift[ifftshift[x]]==x and \
ifftshift[fftshift[x]]==x, even if x has odd length.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"fftshift", "[", 
    RowBox[{"x_", "?", "VectorQ"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "nh"}], "}"}], ",", 
     RowBox[{
      RowBox[{"n", "=", 
       RowBox[{"Length", "[", "x", "]"}]}], ";", 
      RowBox[{"nh", "=", 
       RowBox[{"Ceiling", "[", 
        RowBox[{"0.5", "n"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"x", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"nh", "+", "1"}], ";;", "n"}], "\[RightDoubleBracket]"}], 
        ",", 
        RowBox[{"x", "\[LeftDoubleBracket]", 
         RowBox[{"1", ";;", "nh"}], "\[RightDoubleBracket]"}]}], "]"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ifftshift", "[", 
    RowBox[{"x_", "?", "VectorQ"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "nh"}], "}"}], ",", 
     RowBox[{
      RowBox[{"n", "=", 
       RowBox[{"Length", "[", "x", "]"}]}], ";", 
      RowBox[{"nh", "=", 
       RowBox[{"Floor", "[", 
        RowBox[{"0.5", "n"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"x", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"nh", "+", "1"}], ";;", "n"}], "\[RightDoubleBracket]"}], 
        ",", 
        RowBox[{"x", "\[LeftDoubleBracket]", 
         RowBox[{"1", ";;", "nh"}], "\[RightDoubleBracket]"}]}], "]"}]}]}], 
    "]"}]}], ";"}]}], "Input"],

Cell[TextData[{
 "Power spectral density of a complex vector ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    SubscriptBox["f", "k"], "}"}], TraditionalForm]]],
 " as a vector with elements ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Nu]", "k"], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "/", 
        SubscriptBox["\[CapitalDelta]\[Nu]", "k"]}], ")"}], "|", 
      RowBox[{"FT", "[", 
       SubscriptBox["f", "k"], "]"}], 
      SuperscriptBox["|", "2"]}]}], "}"}], TraditionalForm]]],
 ", where the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Nu]", "k"], TraditionalForm]]],
 " are frequencies (zero-centered). If the time-domain vector is normalized \
to units of Sqrt[W], the PSD is returned in units of W/Hz. Vector sequence is \
appropriate for plotting."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"psd", "[", 
    RowBox[{"ft_", ",", "dt_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"n", "=", 
        RowBox[{"Length", "[", "ft", "]"}]}], ",", "df"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"df", "=", 
       RowBox[{"1.0", "/", 
        RowBox[{"(", 
         RowBox[{"n", " ", "dt"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"df", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{"0", ",", 
              RowBox[{"n", "-", "1"}]}], "]"}], "-", 
            RowBox[{"Ceiling", "[", 
             RowBox[{"n", "/", "2"}], "]"}]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.0", "/", "df"}], ")"}], "*", 
          RowBox[{"fftshift", "[", 
           RowBox[{"absSqr", "[", 
            RowBox[{"ifft", "[", "ft", "]"}], "]"}], "]"}]}]}], "}"}], 
       "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[{
 "The function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[VerticalSeparator]", "f", 
    SuperscriptBox["\[VerticalSeparator]", "2"]}], TraditionalForm]]],
 " which should be faster than ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"Abs", "[", "f", "]"}], "2"], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"absSqr", "[", "x_", "]"}], ":=", 
   RowBox[{"Re", "[", 
    RowBox[{"x", "*", 
     RowBox[{"x", "\[Conjugate]"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"absSqr", "=", " ", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"x", ",", " ", "_Complex", ",", "1"}], "}"}], "}"}], ",", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"Re", "[", "x", "]"}], "^", "2"}], "+", 
      RowBox[{
       RowBox[{"Im", "[", "x", "]"}], "^", "2"}]}]}], "]"}]}], 
  "*)"}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell["Convert dB to a ratio", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dB2ratio", "[", "dB_", "]"}], ":=", 
   RowBox[{"10", "^", 
    RowBox[{"(", 
     RowBox[{"0.1", "dB"}], ")"}]}]}], ";"}]], "Input"],

Cell["Convert a ratio to dB", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ratio2dB", "[", "r_", "]"}], ":=", 
   RowBox[{"10.0", 
    RowBox[{"Log10", "[", "r", "]"}]}]}], ";"}]], "Input"],

Cell["Conversion factor loss from dB/km to 1/m", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dBkm2alpha", "=", 
   RowBox[{"1.0*^-3", "/", 
    RowBox[{"ratio2dB", "[", "E", "]"}]}]}], ";"}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Lorentzian", " ", "function"}], ";", " ", 
   RowBox[{"assumes", " ", "value", " ", "1", " ", "at", " ", "origin"}], ";",
    " ", 
   RowBox[{"integral", " ", "yields", " ", "\[Pi]", "*", 
    RowBox[{"fwhm", "/", "2"}]}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Lor", "[", 
    RowBox[{"x_", ",", "x0_", ",", "fwhm_"}], "]"}], ":=", 
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"4", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x", "-", "x0"}], ")"}], "/", "fwhm"}], ")"}], "^", 
        "2"}]}]}], ")"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Gaussian", "[", 
   RowBox[{"a_", ",", "x_"}], "]"}], ":=", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"a", " ", 
     SqrtBox["\[Pi]"]}]], 
   RowBox[{"Exp", "[", 
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "/", "a"}], ")"}], "2"]}], "]"}]}]}]], "Input",
 InitializationCell->True],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Indicator", " ", "Function"}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"indF", "[", 
   RowBox[{"z_", ",", "n_", ",", "seq_"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"z", ">", 
      RowBox[{"seq", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}],
      "&&", 
     RowBox[{"z", "\[LessEqual]", 
      RowBox[{"seq", "\[LeftDoubleBracket]", 
       RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], ",", "1", ",", 
    "0"}], "]"}]}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ef", "[", "x_", "]"}], ":=", 
   RowBox[{"EngineeringForm", "[", "x", "]"}]}], ";"}]], "Input"],

Cell["Scale some subfields of a vector by factor", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"scaleVec", "[", 
    RowBox[{"vec_", ",", "k_", ",", "factor_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "vec1", "}"}], ",", 
     RowBox[{
      RowBox[{"vec1", "=", "vec"}], ";", 
      RowBox[{
       RowBox[{"vec1", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "k"}], "\[RightDoubleBracket]"}], "*=", 
       "factor"}], ";", "vec1"}]}], "]"}]}], ";"}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell["\<\
Yield True if all elements of a scalar, vector or matrix are machine numbers\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ronMachineNumberQ", "[", "x_", "]"}], ":=", 
  RowBox[{"And", "@@", 
   RowBox[{"Map", "[", 
    RowBox[{"MachineNumberQ", ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", "x", "}"}], "]"}]}], "]"}]}]}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"MATLAB", "'"}], "s", " ", "linspace", 
    RowBox[{"(", ")"}], " ", "routine", " ", "for", " ", "convenience"}], " ",
    "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"linspace", "[", 
     RowBox[{"a_", ",", "b_", ",", 
      RowBox[{"n_:", "100"}]}], "]"}], ":=", 
    RowBox[{"Range", "[", 
     RowBox[{"a", ",", "b", ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"b", "-", "a"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"n", "-", "1"}], ")"}]}]}], "]"}]}], ";"}]}]], "Input",
 InitializationCell->True],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 2}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 4}],

Cell[TextData[{
 StyleBox["Simple implementation of Simpson' s rule\nUsage : simpson (vec, a, \
b)\nvec : vector of length (LEN, 1) with LEN odd and at least 5\na, b : \
integration boundaries\nvec (k) = f (a + (k - 1)*(b - a)/(len - 1)) is \
assumed, for 1 \[LessEqual] k \[LessEqual] LEN\nIn other words, vec (1) = f \
(a) and vec (len) = f (b)\nThen simpson (vec, a, b) approximates \\int_a^b f \
(x) dx\n\nSee \"Springer's Mathe\", p.377\npositions of the bins as the first \
column and the scaled populations as the second column. If one removes the \
Total command you can get the scaled populations for each sublevel, rather \
than the sum of all sublevels. \n\nTranslated to ",
  FontFamily->"Verdana"],
 StyleBox["Mathematica",
  FontFamily->"Verdana",
  FontSlant->"Italic"],
 StyleBox[" on 04Aug10\n\nTest:\nvec1 = Sin[Range[0.0, 11.0, 0.1]];\n\
Simpson[vec1, 0.0, 11.0]\n\t0.995575\nIntegrate[Sin[x], {x, 0.0, 11.0}]\n\t\
0.995574",
  FontFamily->"Verdana"]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"simpson", "[", 
    RowBox[{"vec_", ",", "a_", ",", "b_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"len", ",", "N", ",", "h", ",", "res"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"len", "=", 
       RowBox[{"Length", "[", "vec", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"len", "<", "5"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<Simpson[]:Error:Column vector length must be at least 5 (found \
\>\"", ",", "len", ",", "\"\<)\>\""}], "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"Abort", "[", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"N", "=", 
       RowBox[{"Floor", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"len", "-", "1"}], ")"}], "/", "2"}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"variable", " ", "needed", " ", "in", " ", 
        RowBox[{"Simpson", "'"}], "s", " ", "rule"}], " ", "*)"}], "\n", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"N", "\[NotEqual]", 
         RowBox[{"Ceiling", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"len", "-", "1"}], ")"}], "/", "2"}], "]"}]}], " ", ",", 
        " ", 
        RowBox[{"(*", " ", 
         RowBox[{"len", " ", "is", " ", "even"}], " ", "*)"}], 
        "\[IndentingNewLine]", " ", 
        RowBox[{
         RowBox[{"h", "=", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"b", "-", "a"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", "N"}], ")"}]}], "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"len", "-", "2"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"len", "-", "1"}], ")"}]}]}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
          "approximate", " ", "the", " ", "rest", " ", "using", " ", "a", " ",
            "trapezoidal", " ", "rule"}], "*)"}], "\[IndentingNewLine]", " ", 
         RowBox[{"res", "=", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"vec", "\[LeftDoubleBracket]", 
               RowBox[{"len", "-", "1"}], "\[RightDoubleBracket]"}], "+", 
              RowBox[{
              "vec", "\[LeftDoubleBracket]", "len", 
               "\[RightDoubleBracket]"}]}], ")"}], "/", "2.0"}], "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"b", "-", "a"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"len", "-", "1"}], ")"}]}]}]}], ";"}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"else", " ", "length", " ", "is", " ", "odd"}], ",", 
          RowBox[{
           RowBox[{"Simpson", "'"}], "s", " ", "rule", " ", "alone", " ", 
           "will", " ", "do"}]}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"res", "=", "0.0"}], ";", "\[IndentingNewLine]", 
         RowBox[{"h", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"b", "-", "a"}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"2.0", "*", "N"}], ")"}]}]}], ";"}]}], 
       "\[IndentingNewLine]", "]"}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"If", "[", "]"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"Do", " ", "not", " ", 
         RowBox[{"substitute", "'"}], "2", "*", "N"}], "+", 
        RowBox[{
         RowBox[{"1", "'"}], " ", 
         RowBox[{"for", "'"}], 
         RowBox[{"len", "'"}], " ", "in", " ", "the", " ", "last", " ", 
         "element", " ", "since", " ", "this", " ", "would", " ", "be", " ", 
         "only", " ", "right", " ", "if", " ", "len", " ", "is", " ", 
         "odd"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"res", "+=", 
       RowBox[{
        RowBox[{"h", "/", "3.0"}], "*", 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
          "vec", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "+", 
          RowBox[{"4.0", "*", 
           RowBox[{"Total", "[", 
            RowBox[{"vec", "\[LeftDoubleBracket]", 
             RowBox[{"2", ";;", 
              RowBox[{"2", "*", "N"}], ";;", "2"}], "\[RightDoubleBracket]"}],
             "]"}]}], "+", 
          RowBox[{"2.0", "*", 
           RowBox[{"Total", "[", 
            RowBox[{"vec", "\[LeftDoubleBracket]", 
             RowBox[{"3", ";;", 
              RowBox[{
               RowBox[{"2", "*", "N"}], "-", "1"}], ";;", "2"}], 
             "\[RightDoubleBracket]"}], "]"}]}], "+", 
          RowBox[{"vec", "\[LeftDoubleBracket]", 
           RowBox[{
            RowBox[{"2", "*", "N"}], "+", "1"}], "\[RightDoubleBracket]"}]}], 
         " ", ")"}]}]}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[{
 StyleBox["Smoothen a 1-dim vector a. Code follows ",
  FontFamily->"Verdana"],
 StyleBox["Mathematica",
  FontFamily->"Verdana",
  FontSlant->"Italic"],
 StyleBox[" example. Input: a: 1-dim data vector to smooth, sm: dimensionless \
smoothing parameter (default: 5), doPlot: plot for debugging purposes.\nThe \
larger sm, the weaker will be the smoothing effect.",
  FontFamily->"Verdana"]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"smoothVector", "[", 
    RowBox[{"a_", ",", 
     RowBox[{"sm_:", "5"}], ",", 
     RowBox[{"doPlot_:", "False"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b", ",", "n", ",", "dx", ",", "c"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"See", " ", "help", " ", "for", " ", "Fourier"}], "\[Rule]", 
       RowBox[{"Applications", "\[Rule]", 
        RowBox[{"Filtering", " ", "Data"}]}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"n", "=", 
       RowBox[{"Length", "[", "a", "]"}]}], ";", 
      RowBox[{"dx", "=", 
       RowBox[{"1.", "/", 
        RowBox[{"(", 
         RowBox[{"n", "-", "1"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"b", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"x", "\[LessEqual]", 
            RowBox[{"1", "/", "2"}]}], ",", 
           RowBox[{"Exp", "[", 
            RowBox[{
             RowBox[{"-", "sm"}], " ", "*", "n", "*", " ", 
             RowBox[{"x", "^", "2"}]}], "]"}], ",", 
           RowBox[{"Exp", "[", 
            RowBox[{
             RowBox[{"-", "sm"}], "*", "n", "*", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1.0", "-", "x"}], ")"}], "^", "2"}]}], "]"}]}], "]"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "1", ",", "dx"}], "}"}]}], "]"}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"b", "/=", 
       RowBox[{"Total", "[", "b", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"c", " ", "=", " ", 
       RowBox[{
        RowBox[{"InverseFourier", "[", 
         RowBox[{
          RowBox[{"Fourier", "[", "a", "]"}], " ", 
          RowBox[{"Fourier", "[", "b", "]"}]}], "]"}], 
        RowBox[{"Sqrt", "[", "n", "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{"doPlot", ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ListLinePlot", "[", 
             RowBox[{"b", ",", 
              RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
            RowBox[{"ListLinePlot", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"a", ",", "c"}], "}"}], ",", 
              RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
              RowBox[{"AxesOrigin", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                 "a", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                 ",", "0"}], "}"}]}]}], "]"}]}], "}"}], "]"}], ";"}]}], "]"}],
       ";", "\[IndentingNewLine]", "c"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[{
 StyleBox["Produce a string with rounded numerical value of x with a scaling \
prefix (\[OpenCurlyDoubleQuote]milli\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]kilo\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]Mega\[CloseCurlyDoubleQuote], etc.)\nInput:\n\tx: \
numerical value\n\tdigits: Number of significant digits (default: 3), can \
also be given as {n,k}, where k is numbers to the right of the decimal point\n\
\tisBytes: If True, assume x denotes Bytes and work in basis of 2 rather than \
decimal\nOutput:\n\tString of rounded numerical quantity with scaling prefix \
letter\nExamples:\n\t",
  FontFamily->"Verdana"],
 "uP[0.0000045678]",
 StyleBox[" ---> ",
  FontFamily->"Verdana"],
 "4.57 \[Mu]",
 StyleBox["\n\t",
  FontFamily->"Verdana"],
 "Print[\[OpenCurlyDoubleQuote]Size: \[OpenCurlyDoubleQuote], uP[128*2^30, 3, \
True], \[CloseCurlyDoubleQuote]B\[CloseCurlyDoubleQuote]]  ",
 StyleBox["--->",
  FontFamily->"Verdana"],
 " Size: 128. GB\n\tPrint[uP[55.0*^-33]] ",
 StyleBox["--->  ",
  FontFamily->"Verdana"],
 Cell[BoxData[
  TagBox[
   InterpretationBox[
    RowBox[{"\"\<5.5\>\"", "\[Times]", 
     SuperscriptBox["10", "\"\<-32\>\""]}],
    5.5*^-32,
    AutoDelete->True],
   NumberForm[#, 3]& ]],
  CellChangeTimes->{3.5387190737505536`*^9}]
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{"uP", ",", "uPGdiv", ",", "uPGchar"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"uP", "[", 
    RowBox[{
     RowBox[{"x_", "?", "NumberQ"}], ",", 
     RowBox[{"digits_:", " ", "3"}], ",", 
     RowBox[{"isBytes_:", " ", "False"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"prefixStr", "=", "\"\<fpn\[Mu]m\[VeryThinSpace]kMGT\>\""}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"*", " ", "Select", " ", "the", " ", "prefix", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"m", "\[Equal]", 
           RowBox[{"-", "1"}]}], ":", " ", "milli"}], ",", " ", 
         RowBox[{
          RowBox[{"m", "\[Equal]", "1"}], ":", " ", "kilo"}], ",", " ", 
         RowBox[{
          RowBox[{"m", "\[Equal]", "2"}], ":", " ", "Mega"}], ",", " ", 
         RowBox[{"etc", "."}]}], ")"}]}], " ", "**)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", "isBytes"}], ",", 
         RowBox[{"Ceiling", "[", 
          RowBox[{
           RowBox[{"Log10", "[", 
            RowBox[{
             RowBox[{"Abs", "[", "x", "]"}], "/", "1000.0"}], "]"}], "/", 
           "3.0"}], "]"}], ",", 
         RowBox[{"Floor", "[", 
          RowBox[{
           RowBox[{"Log2", "[", 
            RowBox[{"Abs", "[", "x", "]"}], "]"}], "/", "10.0"}], "]"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"uPGdiv", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", "isBytes"}], ",", 
         RowBox[{"10.0", "^", 
          RowBox[{"(", 
           RowBox[{"3", " ", "m"}], ")"}]}], ",", 
         RowBox[{"2.0", "^", 
          RowBox[{"(", 
           RowBox[{"10", " ", "m"}], ")"}]}]}], "]"}]}], ";", " ", 
      RowBox[{"(*", " ", "divisor", " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"m", "+", "6"}], "<", "1"}], "||", 
         RowBox[{
          RowBox[{"m", "+", "6"}], ">", 
          RowBox[{"StringLength", "[", "prefixStr", "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"uPGchar", "=", "\"\<\>\""}], ";", "\[IndentingNewLine]", 
         RowBox[{"NumberForm", "[", 
          RowBox[{"x", ",", "digits"}], "]"}]}], "  ", 
        RowBox[{"(*", " ", 
         RowBox[{
         "return", " ", "NumberForm", " ", "rather", " ", "than", " ", "a", 
          " ", "string", " ", "to", " ", "preserve", " ", "superscripts", " ",
           "in", " ", "powers", " ", "of", " ", "10"}], " ", "*)"}], 
        "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"uPGchar", "=", 
          RowBox[{"StringTake", "[", 
           RowBox[{"prefixStr", ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"m", ",", "m"}], "}"}], "+", "6"}]}], "]"}]}], ";", " ", 
         RowBox[{"(*", " ", 
          RowBox[{"select", " ", "prefix", " ", "letter"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{
            "\"\<m: \>\"", ",", "m", ",", "\"\<, prefix letter: \>\"", ",", 
             "uPGchar", ",", "\"\<, div: \>\"", ",", "uPGdiv", ",", 
             "\"\<, \>\"", ",", 
             RowBox[{"NumberForm", "[", 
              RowBox[{
               RowBox[{"x", "/", "uPGdiv"}], ",", "digits"}], "]"}]}], "]"}], 
           ";"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"ToString", "[", 
           RowBox[{"NumberForm", "[", 
            RowBox[{
             RowBox[{"x", "/", "uPGdiv"}], ",", "digits"}], "]"}], "]"}], 
          "<>", "\"\<\[VeryThinSpace]\[VeryThinSpace]\[VeryThinSpace]\
\[VeryThinSpace]\>\"", "<>", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"m", "\[Equal]", "0"}], ",", "\"\<\>\"", ",", "uPGchar"}],
            "]"}]}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["Generalization of RotateLeft[] for vectors and \
non-integral shifts\n\tv: input vector\n\tnShift: number of steps to shift \
left (may be non-integer). Positive values shift to left, negative to the \
right.\nOutput:\n\tshifted vector",
 FontFamily->"Verdana"]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rotateLeftRon", "[", 
    RowBox[{"v_", ",", 
     RowBox[{"nShift_:", "1"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ItomegaVec", ",", 
       RowBox[{"nFFT", "=", 
        RowBox[{"Length", "[", "v", "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Mod", "[", 
         RowBox[{"nShift", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"RotateLeft", "[", 
        RowBox[{"v", ",", "nShift"}], "]"}], "\[IndentingNewLine]", ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ItomegaVec", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2.0"}], "\[Pi]", " ", "I", " ", 
            RowBox[{"nShift", "/", "nFFT"}]}], ")"}], "*", 
          RowBox[{"ifftshift", "[", 
           RowBox[{"symFFTVec", "[", "nFFT", "]"}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"InverseFourier", "[", 
         RowBox[{
          RowBox[{"Exp", "[", "ItomegaVec", "]"}], 
          RowBox[{"Fourier", "[", "v", "]"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["Check if an m-file with a given name exists and load \
it unless the current copy is already in memory\nInput:\n\t",
 FontFamily->"Verdana"]], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", "updateMFile", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"updateMFile", "[", "baseName_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"fname", ",", "sym", ",", "fnameIn"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fnameIn", "=", 
       RowBox[{
        RowBox[{"StringReplace", "[", 
         RowBox[{"baseName", ",", 
          RowBox[{"\"\<.m\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}], "<>", 
        "\"\<.m\>\""}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"fname", "=", 
       RowBox[{"FindFile", "[", "fnameIn", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"fname", "\[Equal]", "$Failed"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<loadMFile[]: Cannot find file \>\"", ",", "fnameIn", ",", 
           "\"\< in $Path, Aborting!\>\""}], "]"}], ";", 
         RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{
        "*", " ", "Look", " ", "for", " ", "a", " ", "global", " ", "symbol", 
         " ", "with", " ", "name", " ", "MYFILEwasLoaded"}], ",", " ", 
        RowBox[{
        "but", " ", "remove", " ", "any", " ", "underscores", " ", "from", 
         " ", "variable", " ", "name"}]}], " ", "**)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"sym", "=", 
       RowBox[{"Symbol", "[", 
        RowBox[{
         RowBox[{"StringReplace", "[", 
          RowBox[{"baseName", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"\"\<_\>\"", "\[Rule]", "\"\<\>\""}], ",", 
             RowBox[{"\"\<.m\>\"", "\[Rule]", "\"\<\>\""}]}], "}"}]}], "]"}], 
         "<>", "\"\<wasLoaded\>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"!", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Head", "[", "sym", "]"}], "===", "Real"}], ")"}]}], "||", 
         RowBox[{
          RowBox[{"AbsoluteTime", "[", 
           RowBox[{"FileDate", "[", "fname", "]"}], "]"}], ">", "sym"}]}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Get", "[", "fname", "]"}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"verbosityLevel", ">", "1"}], ",", 
           RowBox[{"Print", "[", 
            RowBox[{"\"\<Loaded file \>\"", ",", "fname"}], "]"}]}], "]"}]}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"verbosityLevel", ">", "1"}], ",", 
          RowBox[{"Print", "[", 
           RowBox[{
           "\"\<File \>\"", ",", "fname", ",", "\"\< is up to date\>\""}], 
           "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 InitializationCell->True],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["Check if a C compiler is installed",
 FontFamily->"Verdana"]], "Text"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<CUDALink`\>\"", "]"}], "\[IndentingNewLine]", 
    "ronCompilationTarget"}], "=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"CUDACCompilers", "[", "]"}], "\[Equal]", 
      RowBox[{"{", "}"}]}], ",", "\"\<WVM\>\"", ",", "\"\<C\>\""}], "]"}]}], 
  " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"ronCompilationTarget", "=", "\"\<C\>\""}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"Check", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"cc1Test", "=", 
       RowBox[{"Compile", "[", " ", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", "x", "}"}], "}"}], ",", 
         RowBox[{
          RowBox[{"x", "^", "2"}], "+", 
          RowBox[{"Sin", "[", 
           RowBox[{"x", "^", "2"}], "]"}]}], ",", 
         RowBox[{"CompilationTarget", "\[Rule]", "\"\<C\>\""}]}], "]"}]}], 
      ";"}], ",", 
     RowBox[{"ronCompilationTarget", "=", "\"\<WVM\>\""}]}], "]"}], ";"}], 
  "*)"}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"Write", " ", "Windows"}], "-", 
     RowBox[{"64", " ", "bit", " ", "identifier", " ", 
      RowBox[{"to", " ", ".", "mx"}], " ", "file", " ", "and", " ", "then", 
      " ", "load", " ", 
      RowBox[{"it", ".", " ", 
       RowBox[{"Errors", ":", " ", 
        RowBox[{
         RowBox[{"-", "1"}], ":", " ", 
         RowBox[{"file", " ", "not", " ", "found"}]}]}]}]}]}], ",", " ", 
    RowBox[{
     RowBox[{"-", "3"}], ":", " ", 
     RowBox[{"ENDCONT", " ", "not", " ", "found", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
        "hence", " ", "possibly", " ", "written", " ", "by", " ", "32"}], "-", 
        RowBox[{"bit", " ", 
         RowBox[{"Windows", "?"}]}]}], ")"}]}]}]}], "   ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ClearAll", "[", "ronGetMX", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ronGetMX", "[", "fname_", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "ret", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"$System", "===", "\"\<Microsoft Windows (64-bit)\>\""}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"ret", " ", "=", " ", 
            RowBox[{"Run", "[", 
             RowBox[{"\"\<TranslateMX \>\"", "<>", "fname"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"ret", "\[NotEqual]", "0"}], ",", 
             RowBox[{
              RowBox[{"Print", "[", 
               RowBox[{
               "\"\<ronGetMX[]: TranslateMX.exe reports error \>\"", ",", 
                "ret", ",", "\"\< on file \>\"", ",", "fname", ",", 
                "\"\< Aborting\>\""}], "]"}], ";", " ", 
              RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";"}]}], " ", 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Get", "[", "fname", "]"}], ";"}]}], "\[IndentingNewLine]", 
      "]"}]}], ";"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Translate", " ", 
    RowBox[{"all", " ", ".", "mx"}], " ", "files", " ", "in", " ", 
    "directory"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ronTranslateMx", "[", 
     RowBox[{"dir_:", "\"\<\>\""}], "]"}], ":=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"StringLength", "[", "dir", "]"}], ">", "0"}], ",", 
        RowBox[{"Check", "[", 
         RowBox[{
          RowBox[{"SetDirectory", "[", "dir", "]"}], ",", 
          RowBox[{"Abort", "[", "]"}]}], "]"}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"$System", "===", "\"\<Microsoft Windows (64-bit)\>\""}], ",", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Run", "[", 
            RowBox[{"\"\<TranslateMX \>\"", "<>", "#"}], "]"}], "&"}], ",", 
          RowBox[{"FileNames", "[", "\"\<*.mx\>\"", "]"}]}], "]"}]}], "]"}]}],
      ")"}]}], ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Translate", " ", 
     RowBox[{"binary", " ", ".", "mx"}], " ", "files", " ", "cross"}], "-", 
    RowBox[{"platform", " ", "on", " ", "little"}], "-", 
    RowBox[{"endian", " ", "systems", " ", "\[IndentingNewLine]", 
     RowBox[{"transWin64", "[", "]"}]}]}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"transWin32Win64", "[", "]"}], ";", 
     RowBox[{"transLinWin64", "[", "]"}]}], ")"}]}], "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Translate", " ", 
     RowBox[{"binary", " ", ".", "mx"}], " ", "files", " ", "cross"}], "-", 
    RowBox[{"platform", " ", "on", " ", "little"}], "-", 
    RowBox[{"endian", " ", "systems"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ClearAll", "[", "translateMX", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"translateMX", "[", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"strs", ",", "n", ",", "n2", ",", "i", ",", "out1"}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"strs", "=", 
        RowBox[{"{", " ", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{
            RowBox[{
            "Use", " ", "a", " ", "hex", " ", "editor", " ", "to", " ", 
             "read", " ", "these", " ", "hex", " ", "strings", " ", "out", 
             " ", "of", " ", "the", " ", "beginning", " ", 
             RowBox[{"of", " ", ".", "mx"}], " ", 
             RowBox[{"files", ".", " ", "They"}], " ", "start", " ", "after", 
             " ", "the", " ", "closing", " ", "bracket", " ", "of", " ", 
             "the", " ", "comment", " ", "and", " ", "end", " ", "just", " ", 
             "before", " ", "the", " ", "string", " ", 
             RowBox[{"\"\<Stage 1\>\"", ".", " ", "Note"}], " ", "that", " ", 
             "they", " ", "all", " ", "have", " ", "the", " ", "same", " ", 
             "string", " ", 
             RowBox[{"length", ".", " ", "When"}], " ", "converting", " ", 
             "from", " ", "the", " ", "old", " ", "32"}], "-", 
            RowBox[{
            "bit", " ", "Windows", " ", "format", " ", "to", " ", "64"}], "-", 
            RowBox[{"bit", " ", "formats"}]}], ",", " ", 
           RowBox[{
            RowBox[{"it", "'"}], "s", " ", "necessary", " ", "to", " ", "cut",
             " ", "part", " ", "of", " ", "the", " ", "comment", " ", "in", 
            " ", "the", " ", "beginnng", " ", "of", " ", 
            RowBox[{"each", " ", ".", "mx"}], " ", "file", " ", "in", " ", 
            "order", " ", "to", " ", "maintain", " ", "the", " ", "total", 
            " ", "file", " ", 
            RowBox[{"length", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
         "\"\<697468204765742E2A2900000808080800000000000020400800000057696E64\
6F77730008000000454E44434F4E540008000000\>\"", ",", " ", 
          RowBox[{"(*", " ", "Win32", " ", "*)"}], "\[IndentingNewLine]", 
          "\"\<2A2900000808080800000000000020400D0000004C696E75782D7838362D363\
40000000008000000454E44434F4E540008000000\>\"", ",", " ", 
          RowBox[{"(*", " ", 
           RowBox[{"Linux64", ",", " ", 
            RowBox[{"Mathematica", " ", "v7"}]}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          "\"\<2A2900000808080800000000000020400F00000057696E646F77732D7838362\
D3634000008000000454E44434F4E540008000000\>\"", ",", " ", 
          RowBox[{"(*", " ", "Win64", " ", "*)"}], "\[IndentingNewLine]", 
          "\"\<2A2900000808080800000000000020400D00000057696e646f777300362D363\
40000000008000000454E44434F4E540008000000\>\"", ",", "  ", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"Linux64", " ", "to", " ", "Win32"}], ",", " ", 
            "\[IndentingNewLine]", 
            RowBox[{"old", " ", "conversion"}]}], "*)"}], 
          "\[IndentingNewLine]", 
          "\"\<2A2900000808080800000000000020400D00000057696E646F7773000000000\
00000000008000000454E44434F4E540008000000\>\"", ",", " ", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"Linux64", " ", "to", " ", "Win32"}], ",", " ", 
            RowBox[{"new", " ", "version"}]}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          "\"\<697468204765742E2A290000080808080000000000001C400800000057696E6\
46F77730008000000454E44434F4E540008000000\>\""}], " ", 
         RowBox[{"(*", " ", 
          RowBox[{"Win32", ",", " ", 
           RowBox[{"old", " ", "version", 
            RowBox[{"(", 
             RowBox[{"?", ")"}], " "}]}]}], "*)"}], "\[IndentingNewLine]", 
         "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"n", "=", 
        RowBox[{"Switch", "[", 
         RowBox[{
         "$System", ",", "\[IndentingNewLine]", 
          "\"\<Microsoft Windows (32-bit)\>\"", ",", "1", ",", 
          "\[IndentingNewLine]", "\"\<Linux (64-bit)\>\"", ",", "2", ",", 
          "\[IndentingNewLine]", "\"\<Microsoft Windows (64-bit)\>\"", ",", 
          "3"}], "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"n", "=", "1"}], ";"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Head", "[", "n", "]"}], "===", "Switch"}], ",", 
         RowBox[{
          RowBox[{"Print", "[", 
           RowBox[{
           "\"\<translateMX[]: Unknown operating system \>\"", ",", 
            "$System"}], "]"}], ";", 
          RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<n: \>\"", ",", "n"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"out1", "=", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{
          RowBox[{"-", "50"}], ",", 
          RowBox[{"Length", "[", "strs", "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
         "\"\<sfk\>\"", " ", "is", " ", "the", " ", 
          "\"\<Swiss File Knife\>\"", " ", "multi"}], "-", 
         RowBox[{"purpose", " ", "utility"}]}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "strs", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{"If", " ", "Linux", " ", "to", " ", "Win32"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"n2", "=", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"i", "\[Equal]", "2"}], "&&", 
              RowBox[{"n", "\[Equal]", "1"}]}], ",", "5", ",", "n"}], "]"}]}],
           ";", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"i", "\[Equal]", "n2"}], ",", 
            RowBox[{"Continue", "[", "]"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{"\"\<sfk replace -bin /\>\"", "<>", 
              RowBox[{
              "strs", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              "<>", "\"\</\>\"", "<>", 
              RowBox[{
              "strs", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              "<>", "\"\</ -dir . -file .mx -yes\>\""}], "]"}], ";"}], " ", 
           "*)"}], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
           "out1", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
           "=", 
           RowBox[{"Run", "[", 
            RowBox[{
            "\"\<\\\"C:\\\\Program Files\\\\bin\\\\sfk\\\" replace -bin \
/\>\"", "<>", 
             RowBox[{
             "strs", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
             "<>", "\"\</\>\"", "<>", 
             RowBox[{
             "strs", "\[LeftDoubleBracket]", "n2", "\[RightDoubleBracket]"}], 
             "<>", "\"\</ -dir . -file .mx -yes\>\""}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Print", "[", 
           RowBox[{"\"\<Code: \>\"", ",", 
            RowBox[{
            "out1", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}], 
           "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
       "\[IndentingNewLine]", "out1"}]}], "\[IndentingNewLine]", 
     "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Run", "[", 
    RowBox[{
    "\"\<\\\"C:\\\\Program Files\\\\bin\\\\sfk\\\" replace -bin /\>\"", "<>", 
     "\"\<2A2900000808080800000000000020400D0000004C696E75782D7838362D36340000\
000008000000454E44434F4E540008000000\>\"", "<>", "\"\</\>\"", "<>", 
     "\"\<2A2900000808080800000000000020400D00000057696E646F777300000000000000\
000008000000454E44434F4E540008000000\>\"", "<>", 
     "\"\</ -dir . -file .mx -yes\>\""}], "]"}], ";"}], "\[IndentingNewLine]",
   "*)"}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowSize->{1211, 805},
WindowMargins->{{60, Automatic}, {Automatic, 49}},
TrackCellChangeTimes->False,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[620, 21, 117, 3, 31, "Input"],
Cell[CellGroupData[{
Cell[762, 28, 52, 1, 83, "Title",
 InitializationGroup->True],
Cell[817, 31, 135, 2, 45, "Text",
 InitializationGroup->True],
Cell[955, 35, 124, 5, 83, "Text"],
Cell[1082, 42, 2786, 71, 212, "Input"],
Cell[3871, 115, 503, 14, 72, "Input"],
Cell[4377, 131, 392, 11, 52, "Input"],
Cell[4772, 144, 797, 26, 52, "Input"],
Cell[5572, 172, 2411, 68, 95, "Input"],
Cell[CellGroupData[{
Cell[8008, 244, 51, 1, 71, "Section",
 InitializationGroup->True],
Cell[8062, 247, 95, 2, 31, "Input"],
Cell[8160, 251, 273, 4, 45, "Text",
 InitializationGroup->True],
Cell[8436, 257, 251, 6, 31, "Input"],
Cell[8690, 265, 1448, 39, 72, "Input",
 InitializationCell->True,
 InitializationGroup->True],
Cell[10141, 306, 273, 9, 5, "Text"],
Cell[10417, 317, 2807, 74, 132, "Input"],
Cell[13227, 393, 273, 9, 5, "Text"],
Cell[13503, 404, 1409, 37, 92, "Input"],
Cell[14915, 443, 273, 9, 5, "Text"],
Cell[15191, 454, 1457, 38, 92, "Input"],
Cell[16651, 494, 273, 9, 5, "Text"],
Cell[16927, 505, 1463, 38, 92, "Input"],
Cell[18393, 545, 273, 9, 5, "Text"],
Cell[18669, 556, 1401, 37, 72, "Input"],
Cell[20073, 595, 273, 9, 5, "Text"],
Cell[20349, 606, 63, 0, 29, "Text"],
Cell[20415, 608, 860, 20, 52, "Input",
 InitializationCell->True,
 InitializationGroup->True],
Cell[21278, 630, 273, 9, 5, "Text"],
Cell[21554, 641, 1164, 37, 31, "Input"],
Cell[22721, 680, 273, 9, 5, "Text"],
Cell[22997, 691, 798, 14, 263, "Text"],
Cell[23798, 707, 588, 19, 52, "Input"],
Cell[24389, 728, 2058, 58, 292, "Input"],
Cell[26450, 788, 244, 4, 29, "Text"],
Cell[26697, 794, 349, 11, 31, "Input"],
Cell[27049, 807, 151, 3, 29, "Text"],
Cell[27203, 812, 1616, 46, 132, "Input"],
Cell[28822, 860, 833, 26, 49, "Text"],
Cell[29658, 888, 1134, 34, 92, "Input"],
Cell[30795, 924, 273, 9, 5, "Text"],
Cell[31071, 935, 323, 11, 29, "Text"],
Cell[31397, 948, 190, 6, 31, "Input"],
Cell[31590, 956, 408, 13, 31, "Input"],
Cell[32001, 971, 273, 9, 5, "Text"],
Cell[32277, 982, 37, 0, 29, "Text"],
Cell[32317, 984, 180, 6, 31, "Input"],
Cell[32500, 992, 37, 0, 29, "Text"],
Cell[32540, 994, 161, 5, 31, "Input"],
Cell[32704, 1001, 56, 0, 29, "Text"],
Cell[32763, 1003, 143, 4, 31, "Input"],
Cell[32909, 1009, 273, 9, 5, "Text"],
Cell[33185, 1020, 273, 9, 5, "Text"],
Cell[33461, 1031, 306, 7, 31, "Input"],
Cell[33770, 1040, 401, 14, 31, "Input"],
Cell[34174, 1056, 355, 13, 52, "Input",
 InitializationCell->True],
Cell[34532, 1071, 273, 9, 5, "Text"],
Cell[34808, 1082, 99, 2, 31, "Input"],
Cell[34910, 1086, 457, 13, 31, "Input"],
Cell[35370, 1101, 273, 9, 5, "Text"],
Cell[35646, 1112, 142, 4, 31, "Input"],
Cell[35791, 1118, 58, 0, 29, "Text"],
Cell[35852, 1120, 455, 13, 31, "Input"],
Cell[36310, 1135, 273, 9, 5, "Text"],
Cell[36586, 1146, 100, 2, 29, "Text"],
Cell[36689, 1150, 254, 7, 31, "Input"],
Cell[36946, 1159, 273, 9, 5, "Text"],
Cell[37222, 1170, 622, 19, 52, "Input",
 InitializationCell->True],
Cell[37847, 1191, 271, 9, 8, "Text"],
Cell[38121, 1202, 981, 18, 351, "Text"],
Cell[39105, 1222, 5069, 128, 392, "Input"],
Cell[44177, 1352, 273, 9, 5, "Text"],
Cell[44453, 1363, 418, 10, 62, "Text"],
Cell[44874, 1375, 2871, 76, 212, "Input"],
Cell[47748, 1453, 273, 9, 5, "Text"],
Cell[48024, 1464, 1305, 33, 201, "Text"],
Cell[49332, 1499, 4210, 107, 292, "Input"],
Cell[53545, 1608, 273, 9, 5, "Text"],
Cell[53821, 1619, 295, 4, 96, "Text"],
Cell[54119, 1625, 1309, 37, 172, "Input"],
Cell[55431, 1664, 273, 9, 5, "Text"],
Cell[55707, 1675, 174, 2, 62, "Text"],
Cell[55884, 1679, 2973, 76, 252, "Input",
 InitializationCell->True],
Cell[58860, 1757, 273, 9, 5, "Text"],
Cell[59136, 1768, 94, 1, 28, "Text"],
Cell[59233, 1771, 381, 11, 52, "Input"],
Cell[59617, 1784, 669, 20, 52, "Input"],
Cell[60289, 1806, 273, 9, 5, "Text"],
Cell[60565, 1817, 2148, 55, 212, "Input"],
Cell[62716, 1874, 1050, 29, 72, "Input"],
Cell[63769, 1905, 491, 12, 52, "Input"],
Cell[64263, 1919, 8060, 176, 732, "Input"],
Cell[72326, 2097, 558, 11, 112, "Input"],
Cell[72887, 2110, 273, 9, 5, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)
:\n\tshifted vector",
 FontFamily->"Verdana"]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rotateLeftRon", "[", 
    RowBox[{"v_", ",", 
     RowBox[{"nShift_:", "1"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ItomegaVec", ",", 
       RowBox[{"nFFT", "=", 
        RowBox[{"Length", "[", "v", "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Mod", "[", 
         RowBox[{"nShift", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"RotateLeft", "[", 
        RowBox[{"v", ",", "nShift"}], "]"}], "\[IndentingNewLine]", ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ItomegaVec", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2.0"}], "\[Pi]", " ", "I", " ", 
            RowBox[{"nShift", "/", "nFFT"}]}], ")"}], "*", 
          RowBox[{"ifftshift", "[", 
           RowBox[{"symFFTVec", "[", "nFFT", "]"}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"InverseFourier", "[", 
         RowBox[{
          RowBox[{"Exp", "[", "ItomegaVec", "]"}], 
          RowBox[{"Fourier", "[", "v", "]"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["Check if an m-file with a given name exists and load \
it unless the current copy is already in memory\nInput:\n\t",
 FontFamily->"Verdana"]], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", "updateMFile", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"updateMFile", "[", "baseName_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"fname", ",", "sym", ",", "fnameIn"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fnameIn", "=", 
       RowBox[{
        RowBox[{"StringReplace", "[", 
         RowBox[{"baseName", ",", 
          RowBox[{"\"\<.m\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}], "<>", 
        "\"\<.m\>\""}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"fname", "=", 
       RowBox[{"FindFile", "[", "fnameIn", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"fname", "\[Equal]", "$Failed"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<loadMFile[]: Cannot find file \>\"", ",", "fnameIn", ",", 
           "\"\< in $Path, Aborting!\>\""}], "]"}], ";", 
         RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{
        "*", " ", "Look", " ", "for", " ", "a", " ", "global", " ", "symbol", 
         " ", "with", " ", "name", " ", "MYFILEwasLoaded"}], ",", " ", 
        RowBox[{
        "but", " ", "remove", " ", "any", " ", "underscores", " ", "from", 
         " ", "variable", " ", "name"}]}], " ", "**)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"sym", "=", 
       RowBox[{"Symbol", "[", 
        RowBox[{
         RowBox[{"StringReplace", "[", 
          RowBox[{"baseName", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"\"\<_\>\"", "\[Rule]", "\"\<\>\""}], ",", 
             RowBox[{"\"\<.m\>\"", "\[Rule]", "\"\<\>\""}]}], "}"}]}], "]"}], 
         "<>", "\"\<wasLoaded\>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"!", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Head", "[", "sym", "]"}], "===", "Real"}], ")"}]}], "||", 
         RowBox[{
          RowBox[{"AbsoluteTime", "[", 
           RowBox[{"FileDate", "[", "fname", "]"}], "]"}], ">", "sym"}]}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Get", "[", "fname", "]"}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"verbosityLevel", ">", "1"}], ",", 
           RowBox[{"Print", "[", 
            RowBox[{"\"\<Loaded file \>\"", ",", "fname"}], "]"}]}], "]"}]}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"verbosityLevel", ">", "1"}], ",", 
          RowBox[{"Print", "[", 
           RowBox[{
           "\"\<File \>\"", ",", "fname", ",", "\"\< is up to date\>\""}], 
           "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 InitializationCell->True],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["Check if a C compiler is installed",
 FontFamily->"Verdana"]], "Text"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<CUDALink`\>\"", "]"}], "\[IndentingNewLine]", 
    "ronCompilationTarget"}], "=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"CUDACCompilers", "[", "]"}], "\[Equal]", 
      RowBox[{"{", "}"}]}], ",", "\"\<WVM\>\"", ",", "\"\<C\>\""}], "]"}]}], 
  " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"ronCompilationTarget", "=", "\"\<C\>\""}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"Check", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"cc1Test", "=", 
       RowBox[{"Compile", "[", " ", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", "x", "}"}], "}"}], ",", 
         RowBox[{
          RowBox[{"x", "^", "2"}], "+", 
          RowBox[{"Sin", "[", 
           RowBox[{"x", "^", "2"}], "]"}]}], ",", 
         RowBox[{"CompilationTarget", "\[Rule]", "\"\<C\>\""}]}], "]"}]}], 
      ";"}], ",", 
     RowBox[{"ronCompilationTarget", "=", "\"\<WVM\>\""}]}], "]"}], ";"}], 
  "*)"}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"Write", " ", "Windows"}], "-", 
     RowBox[{"64", " ", "bit", " ", "identifier", " ", 
      RowBox[{"to", " ", ".", "mx"}], " ", "file", " ", "and", " ", "then", 
      " ", "load", " ", 
      RowBox[{"it", ".", " ", 
       RowBox[{"Errors", ":", " ", 
        RowBox[{
         RowBox[{"-", "1"}], ":", " ", 
         RowBox[{"file", " ", "not", " ", "found"}]}]}]}]}]}], ",", " ", 
    RowBox[{
     RowBox[{"-", "3"}], ":", " ", 
     RowBox[{"ENDCONT", " ", "not", " ", "found", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
        "hence", " ", "possibly", " ", "written", " ", "by", " ", "32"}], "-", 
        RowBox[{"bit", " ", 
         RowBox[{"Windows", "?"}]}]}], ")"}]}]}]}], "   ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ClearAll", "[", "ronGetMX", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ronGetMX", "[", "fname_", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "ret", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"$System", "===", "\"\<Microsoft Windows (64-bit)\>\""}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"ret", " ", "=", " ", 
            RowBox[{"Run", "[", 
             RowBox[{"\"\<TranslateMX \>\"", "<>", "fname"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"ret", "\[NotEqual]", "0"}], ",", 
             RowBox[{
              RowBox[{"Print", "[", 
               RowBox[{
               "\"\<ronGetMX[]: TranslateMX.exe reports error \>\"", ",", 
                "ret", ",", "\"\< on file \>\"", ",", "fname", ",", 
                "\"\< Aborting\>\""}], "]"}], ";", " ", 
              RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";"}]}], " ", 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Get", "[", "fname", "]"}], ";"}]}], "\[IndentingNewLine]", 
      "]"}]}], ";"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Translate", " ", 
    RowBox[{"all", " ", ".", "mx"}], " ", "files", " ", "in", " ", 
    "directory"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ronTranslateMx", "[", 
     RowBox[{"dir_:", "\"\<\>\""}], "]"}], ":=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"StringLength", "[", "dir", "]"}], ">", "0"}], ",", 
        RowBox[{"Check", "[", 
         RowBox[{
          RowBox[{"SetDirectory", "[", "dir", "]"}], ",", 
          RowBox[{"Abort", "[", "]"}]}], "]"}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"$System", "===", "\"\<Microsoft Windows (64-bit)\>\""}], ",", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Run", "[", 
            RowBox[{"\"\<TranslateMX \>\"", "<>", "#"}], "]"}], "&"}], ",", 
          RowBox[{"FileNames", "[", "\"\<*.mx\>\"", "]"}]}], "]"}]}], "]"}]}],
      ")"}]}], ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Translate", " ", 
     RowBox[{"binary", " ", ".", "mx"}], " ", "files", " ", "cross"}], "-", 
    RowBox[{"platform", " ", "on", " ", "little"}], "-", 
    RowBox[{"endian", " ", "systems", " ", "\[IndentingNewLine]", 
     RowBox[{"transWin64", "[", "]"}]}]}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"transWin32Win64", "[", "]"}], ";", 
     RowBox[{"transLinWin64", "[", "]"}]}], ")"}]}], "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Translate", " ", 
     RowBox[{"binary", " ", ".", "mx"}], " ", "files", " ", "cross"}], "-", 
    RowBox[{"platform", " ", "on", " ", "little"}], "-", 
    RowBox[{"endian", " ", "systems"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ClearAll", "[", "translateMX", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"translateMX", "[", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"strs", ",", "n", ",", "n2", ",", "i", ",", "out1"}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"strs", "=", 
        RowBox[{"{", " ", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{
            RowBox[{
            "Use", " ", "a", " ", "hex", " ", "editor", " ", "to", " ", 
             "read", " ", "these", " ", "hex", " ", "strings", " ", "out", 
             " ", "of", " ", "the", " ", "beginning", " ", 
             RowBox[{"of", " ", ".", "mx"}], " ", 
             RowBox[{"files", ".", " ", "They"}], " ", "start", " ", "after", 
             " ", "the", " ", "closing", " ", "bracket", " ", "of", " ", 
             "the", " ", "comment", " ", "and", " ", "end", " ", "just", " ", 
             "before", " ", "the", " ", "string", " ", 
             RowBox[{"\"\<Stage 1\>\"", ".", " ", "Note"}], " ", "that", " ", 
             "they", " ", "all", " ", "have", " ", "the", " ", "same", " ", 
             "string", " ", 
             RowBox[{"length", ".", " ", "When"}], " ", "converting", " ", 
             "from", " ", "the", " ", "old", " ", "32"}], "-", 
            RowBox[{
            "bit", " ", "Windows", " ", "format", " ", "to", " ", "64"}], "-", 
            RowBox[{"bit", " ", "formats"}]}], ",", " ", 
           RowBox[{
            RowBox[{"it", "'"}], "s", " ", "necessary", " ", "to", " ", "cut",
             " ", "part", " ", "of", " ", "the", " ", "comment", " ", "in", 
            " ", "the", " ", "beginnng", " ", "of", " ", 
            RowBox[{"each", " ", ".", "mx"}], " ", "file", " ", "in", " ", 
            "order", " ", "to", " ", "maintain", " ", "the", " ", "total", 
            " ", "file", " ", 
            RowBox[{"length", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
         "\"\<697468204765742E2A2900000808080800000000000020400800000057696E64\
6F77730008000000454E44434F4E540008000000\>\"", ",", " ", 
          RowBox[{"(*", " ", "Win32", " ", "*)"}], "\[IndentingNewLine]", 
          "\"\<2A2900000808080800000000000020400D0000004C696E75782D7838362D363\
40000000008000000454E44434F4E540008000000\>\"", ",", " ", 
          RowBox[{"(*", " ", 
           RowBox[{"Linux64", ",", " ", 
            RowBox[{"Mathematica", " ", "v7"}]}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          "\"\<2A2900000808080800000000000020400F00000057696E646F77732D7838362\
D3634000008000000454E44434F4E540008000000\>\"", ",", " ", 
          RowBox[{"(*", " ", "Win64", " ", "*)"}], "\[IndentingNewLine]", 
          "\"\<2A2900000808080800000000000020400D00000057696e646f777300362D363\
40000000008000000454E44434F4E540008000000\>\"", ",", "  ", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"Linux64", " ", "to", " ", "Win32"}], ",", " ", 
            "\[IndentingNewLine]", 
            RowBox[{"old", " ", "conversion"}]}], "*)"}], 
          "\[IndentingNewLine]", 
          "\"\<2A2900000808080800000000000020400D00000057696E646F7773000000000\
00000000008000000454E44434F4E540008000000\>\"", ",", " ", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"Linux64", " ", "to", " ", "Win32"}], ",", " ", 
            RowBox[{"new", " ", "version"}]}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          "\"\<697468204765742E2A290000080808080000000000001C400800000057696E6\
46F77730008000000454E44434F4E540008000000\>\""}], " ", 
         RowBox[{"(*", " ", 
          RowBox[{"Win32", ",", " ", 
           RowBox[{"old", " ", "version", 
            RowBox[{"(", 
             RowBox[{"?", ")"}], " "}]}]}], "*)"}], "\[IndentingNewLine]", 
         "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"n", "=", 
        RowBox[{"Switch", "[", 
         RowBox[{
         "$System", ",", "\[IndentingNewLine]", 
          "\"\<Microsoft Windows (32-bit)\>\"", ",", "1", ",", 
          "\[IndentingNewLine]", "\"\<Linux (64-bit)\>\"", ",", "2", ",", 
          "\[IndentingNewLine]", "\"\<Microsoft Windows (64-bit)\>\"", ",", 
          "3"}], "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"n", "=", "1"}], ";"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Head", "[", "n", "]"}], "===", "Switch"}], ",", 
         RowBox[{
          RowBox[{"Print", "[", 
           RowBox[{
           "\"\<translateMX[]: Unknown operating system \>\"", ",", 
            "$System"}], "]"}], ";", 
          RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<n: \>\"", ",", "n"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"out1", "=", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{
          RowBox[{"-", "50"}], ",", 
          RowBox[{"Length", "[", "strs", "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
         "\"\<sfk\>\"", " ", "is", " ", "the", " ", 
          "\"\<Swiss File Knife\>\"", " ", "multi"}], "-", 
         RowBox[{"purpose", " ", "utility"}]}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"i", "=", "1"}], ",", 
          RowBox[{"i", "\[LessEqual]", 
           RowBox[{"Length", "[", "strs", "]"}]}], ",", 
          RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"If", " ", "Linux", " ", "to", " ", "Win32"}], " ", "*)"}],
           "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"n2", "=", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"i", "\[Equal]", "2"}], "&&", 
               RowBox[{"n", "\[Equal]", "1"}]}], ",", "5", ",", "n"}], 
             "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"i", "\[Equal]", "n2"}], ",", 
             RowBox[{"Continue", "[", "]"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"(*", " ", 
            RowBox[{
             RowBox[{"Print", "[", 
              RowBox[{"\"\<sfk replace -bin /\>\"", "<>", 
               RowBox[{
               "strs", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "<>", "\"\</\>\"", "<>", 
               RowBox[{
               "strs", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                "<>", "\"\</ -dir . -file .mx -yes\>\""}], "]"}], ";"}], " ", 
            "*)"}], "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
            "out1", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "=", 
            RowBox[{"Run", "[", 
             RowBox[{
             "\"\<\\\"C:\\\\Program Files\\\\bin\\\\sfk\\\" replace -bin \
/\>\"", "<>", 
              RowBox[{
              "strs", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              "<>", "\"\</\>\"", "<>", 
              RowBox[{
              "strs", "\[LeftDoubleBracket]", "n2", "\[RightDoubleBracket]"}],
               "<>", "\"\</ -dir . -file .mx -yes\>\""}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"Print", "[", 
            RowBox[{"\"\<Code: \>\"", ",", 
             RowBox[{
             "out1", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}],
             "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
        "\[IndentingNewLine]", "out1"}]}]}], "\[IndentingNewLine]", 
     "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Run", "[", 
    RowBox[{
    "\"\<\\\"C:\\\\Program Files\\\\bin\\\\sfk\\\" replace -bin /\>\"", "<>", 
     "\"\<2A2900000808080800000000000020400D0000004C696E75782D7838362D36340000\
000008000000454E44434F4E540008000000\>\"", "<>", "\"\</\>\"", "<>", 
     "\"\<2A2900000808080800000000000020400D00000057696E646F777300000000000000\
000008000000454E44434F4E540008000000\>\"", "<>", 
     "\"\</ -dir . -file .mx -yes\>\""}], "]"}], ";"}], "\[IndentingNewLine]",
   "*)"}]], "Input"],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowSize->{1211, 805},
WindowMargins->{{60, Automatic}, {Automatic, 49}},
TrackCellChangeTimes->False,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (February 23, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 117, 3, 31, "Input"],
Cell[CellGroupData[{
Cell[699, 27, 52, 1, 83, "Title",
 InitializationGroup->True],
Cell[754, 30, 135, 2, 45, "Text",
 InitializationGroup->True],
Cell[892, 34, 124, 5, 83, "Text"],
Cell[1019, 41, 2786, 71, 212, "Input"],
Cell[3808, 114, 503, 14, 72, "Input"],
Cell[4314, 130, 392, 11, 52, "Input"],
Cell[4709, 143, 797, 26, 52, "Input"],
Cell[5509, 171, 2411, 68, 95, "Input"],
Cell[CellGroupData[{
Cell[7945, 243, 51, 1, 71, "Section",
 InitializationGroup->True],
Cell[7999, 246, 95, 2, 31, "Input"],
Cell[8097, 250, 273, 4, 45, "Text",
 InitializationGroup->True],
Cell[8373, 256, 251, 6, 31, "Input"],
Cell[8627, 264, 1448, 39, 72, "Input",
 InitializationCell->True,
 InitializationGroup->True],
Cell[10078, 305, 273, 9, 5, "Text"],
Cell[10354, 316, 2807, 74, 132, "Input"],
Cell[13164, 392, 273, 9, 5, "Text"],
Cell[13440, 403, 1409, 37, 92, "Input"],
Cell[14852, 442, 273, 9, 5, "Text"],
Cell[15128, 453, 1457, 38, 92, "Input"],
Cell[16588, 493, 273, 9, 5, "Text"],
Cell[16864, 504, 1463, 38, 92, "Input"],
Cell[18330, 544, 273, 9, 5, "Text"],
Cell[18606, 555, 1401, 37, 72, "Input"],
Cell[20010, 594, 273, 9, 5, "Text"],
Cell[20286, 605, 63, 0, 29, "Text"],
Cell[20352, 607, 860, 20, 52, "Input",
 InitializationCell->True,
 InitializationGroup->True],
Cell[21215, 629, 273, 9, 5, "Text"],
Cell[21491, 640, 1164, 37, 31, "Input"],
Cell[22658, 679, 273, 9, 5, "Text"],
Cell[22934, 690, 798, 14, 263, "Text"],
Cell[23735, 706, 588, 19, 52, "Input"],
Cell[24326, 727, 2058, 58, 292, "Input"],
Cell[26387, 787, 244, 4, 29, "Text"],
Cell[26634, 793, 349, 11, 31, "Input"],
Cell[26986, 806, 151, 3, 29, "Text"],
Cell[27140, 811, 1616, 46, 132, "Input"],
Cell[28759, 859, 833, 26, 49, "Text"],
Cell[29595, 887, 1134, 34, 92, "Input"],
Cell[30732, 923, 273, 9, 5, "Text"],
Cell[31008, 934, 323, 11, 29, "Text"],
Cell[31334, 947, 190, 6, 31, "Input"],
Cell[31527, 955, 408, 13, 31, "Input"],
Cell[31938, 970, 273, 9, 5, "Text"],
Cell[32214, 981, 37, 0, 29, "Text"],
Cell[32254, 983, 180, 6, 31, "Input"],
Cell[32437, 991, 37, 0, 29, "Text"],
Cell[32477, 993, 161, 5, 31, "Input"],
Cell[32641, 1000, 56, 0, 29, "Text"],
Cell[32700, 1002, 143, 4, 31, "Input"],
Cell[32846, 1008, 273, 9, 5, "Text"],
Cell[33122, 1019, 273, 9, 5, "Text"],
Cell[33398, 1030, 306, 7, 31, "Input"],
Cell[33707, 1039, 401, 14, 31, "Input"],
Cell[34111, 1055, 355, 13, 52, "Input",
 InitializationCell->True],
Cell[34469, 1070, 273, 9, 5, "Text"],
Cell[34745, 1081, 99, 2, 31, "Input"],
Cell[34847, 1085, 457, 13, 31, "Input"],
Cell[35307, 1100, 273, 9, 5, "Text"],
Cell[35583, 1111, 142, 4, 31, "Input"],
Cell[35728, 1117, 58, 0, 29, "Text"],
Cell[35789, 1119, 455, 13, 31, "Input"],
Cell[36247, 1134, 273, 9, 5, "Text"],
Cell[36523, 1145, 100, 2, 29, "Text"],
Cell[36626, 1149, 254, 7, 31, "Input"],
Cell[36883, 1158, 273, 9, 5, "Text"],
Cell[37159, 1169, 622, 19, 52, "Input",
 InitializationCell->True],
Cell[37784, 1190, 271, 9, 8, "Text"],
Cell[38058, 1201, 981, 18, 351, "Text"],
Cell[39042, 1221, 5069, 128, 392, "Input"],
Cell[44114, 1351, 273, 9, 5, "Text"],
Cell[44390, 1362, 418, 10, 62, "Text"],
Cell[44811, 1374, 2871, 76, 212, "Input"],
Cell[47685, 1452, 273, 9, 5, "Text"],
Cell[47961, 1463, 1305, 33, 201, "Text"],
Cell[49269, 1498, 4129, 106, 292, "Input"],
Cell[53401, 1606, 273, 9, 5, "Text"],
Cell[53677, 1617, 295, 4, 96, "Text"],
Cell[53975, 1623, 1309, 37, 172, "Input"],
Cell[55287, 1662, 273, 9, 5, "Text"],
Cell[55563, 1673, 174, 2, 62, "Text"],
Cell[55740, 1677, 2973, 76, 252, "Input",
 InitializationCell->True],
Cell[58716, 1755, 273, 9, 5, "Text"],
Cell[58992, 1766, 94, 1, 28, "Text"],
Cell[59089, 1769, 381, 11, 52, "Input"],
Cell[59473, 1782, 669, 20, 52, "Input"],
Cell[60145, 1804, 273, 9, 5, "Text"],
Cell[60421, 1815, 2148, 55, 212, "Input"],
Cell[62572, 1872, 1050, 29, 72, "Input"],
Cell[63625, 1903, 491, 12, 52, "Input"],
Cell[64119, 1917, 8128, 177, 732, "Input"],
Cell[72250, 2096, 558, 11, 112, "Input"],
Cell[72811, 2109, 273, 9, 5, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
